==> enterprisemodules-wls_config-3.3.15.tar.gz: enterprisemodules-wls_config-3.3.15/lib/puppet/type/wls_foreign_jndi_provider_link.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_foreign_jndi_provider_link) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
      This resource allows you to manage a datasource in an WebLogic domain.

      Here is an example on how you should use this:

          wls_foreign_jndi_provider_link { 'LDAP:aaaaa':
            ensure           => 'present',
            local_jndi_name  => 'aaaaa',
            remote_jndi_name => 'bbbbb',
          }

      In this example you are managing a foreign jndi provider link in the default domain. When you want to
      manage a foreign jndi provider link in a specific domain, you can use:

          wls_foreign_jndi_provider_link { 'my_domain/LDAP:ccccc':
            ensure           => 'present',
            local_jndi_name  => 'ccccc',
            remote_jndi_name => 'ddddd',
          }

    EOD

    bean_type('ForeignJNDILink')
    bean_path('/ForeignJNDIProviders/%{provider_name}/ForeignJNDILinks')

    ensurable
    parameter :domain
    parameter :name
    parameter :link_name
    parameter :provider_name

    property  :local_jndi_name
    property  :remote_jndi_name
    extraproperties do
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
    end

    add_title_attributes(:provider_name, :link_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.12.2.tar.gz: enterprisemodules-wls_config-3.12.2/lib/puppet/type/wls_foreign_jndi_provider_link.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_foreign_jndi_provider_link) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
      This resource allows you to manage a datasource in an WebLogic domain.

      Here is an example on how you should use this:

          wls_foreign_jndi_provider_link { 'LDAP:aaaaa':
            ensure           => 'present',
            local_jndi_name  => 'aaaaa',
            remote_jndi_name => 'bbbbb',
          }

      In this example you are managing a foreign jndi provider link in the default domain. When you want to
      manage a foreign jndi provider link in a specific domain, you can use:

          wls_foreign_jndi_provider_link { 'my_domain/LDAP:ccccc':
            ensure           => 'present',
            local_jndi_name  => 'ccccc',
            remote_jndi_name => 'ddddd',
          }

    DESC

    bean_type('ForeignJNDILink')
    bean_path('/ForeignJNDIProviders/%<provider_name>s/ForeignJNDILinks')

    ensurable
    parameter :domain
    parameter :name
    parameter :link_name
    parameter :provider_name

    property  :local_jndi_name
    property  :remote_jndi_name
    extraproperties do
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
    end

    add_title_attributes(:provider_name, :link_name) do
      /(.+):(.+)/
    end
  end
end
